pub struct BatchQueryBuilder<'d> { /* private fields */ }Expand description
A builder for configuring and executing batch dictionary lookups.
Implementations
Sourceimpl<'d> BatchQueryBuilder<'d>
impl<'d> BatchQueryBuilder<'d>
Sourcepub fn common_only(self, common: bool) -> Self
pub fn common_only(self, common: bool) -> Self
Filter to entries where any KanjiEntry or KanaEntry has common: true.
Sourcepub fn pos(self, pos: &[&str]) -> Self
pub fn pos(self, pos: &[&str]) -> Self
Filter to entries with matching part_of_speech values in any SenseEntry.
Sourcepub fn misc(self, misc: &[&str]) -> Self
pub fn misc(self, misc: &[&str]) -> Self
Filter to entries with any of the given JMdict misc codes.
Sourcepub fn field(self, field: &[&str]) -> Self
pub fn field(self, field: &[&str]) -> Self
Filter to entries with any of the given JMdict field codes.
Sourcepub fn dialect(self, dialect: &[&str]) -> Self
pub fn dialect(self, dialect: &[&str]) -> Self
Filter to entries with any of the given JMdict dialect codes.
Sourcepub fn max_distance(self, n: u32) -> Self
pub fn max_distance(self, n: u32) -> Self
Set the maximum edit distance for fuzzy search (default: 2).
Clamped to a maximum of MAX_FUZZY_DISTANCE.
Sourcepub fn execute(self) -> Result<Vec<(String, Vec<LookupResult>)>, JmdictError>
pub fn execute(self) -> Result<Vec<(String, Vec<LookupResult>)>, JmdictError>
Execute the batch query and return results paired with each input term.